@@ -1,9 +1,10 @@
-from .request import Request, HttpRequest, WebSocketRequest
+from .request import Request, HttpRequest, MediaRequest, WebSocketRequest
 from .response import Response, HttpResponse, WebSocketResponse
 
 __all__ = [
     "Request",
     "HttpRequest",
+    "MediaRequest",
     "WebSocketRequest",
     "Response",
     "HttpResponse",
