@@ -1,7 +1,9 @@
 from .base import Extension
 from .signal_manager import SignalManager
+from .singal_info import SignalInfo
 
 __all__ = [
     "Extension",
     "SignalManager",
+    "SignalInfo",
 ]
\ No newline at end of file
