@@ -1,17 +1,21 @@
 from typing import Protocol, TYPE_CHECKING, Dict
 if TYPE_CHECKING:
-    from ..models.api import SingalInfo
+    from ..extensions import SignalInfo
 
 class SignalHooks(Protocol):
-    def send(self, signal: object, data: "SingalInfo") -> None: ...
+    def send(self, signal: object, data: "SignalInfo") -> None: ...
 
-class SessionHooks(Protocol):
+class _SessionHooks(Protocol):
     def mark_end(self, session_id: str) -> None: ...
 
     def get_session_cookies(self, session_id: str) -> Dict: ...
 
+class SessionHooks(Protocol):
+    def get_session_cookies(self, session_id: str) -> Dict: ...
+
 class _PipelinesHooks(Protocol):
-    session: SessionHooks
+    session: _SessionHooks
 
 class PipelinesHooks(Protocol):
+    session: SessionHooks
     signals: SignalHooks
\ No newline at end of file
