@@ -50,7 +50,6 @@ class UpdateRequestSpiderInterceptor(_InnerSpiderInterceptor):
         self.timeout = self.settings.TIMEOUT
         self.dont_filter = self.settings.DONT_FILTER
         self.proxies = self.settings.PROXIES
-        self.proxies_list = self.settings.PROXIES_LIST
         self.proxies_list = [{"http": proxy_url, "https": proxy_url} for proxy_url in self.settings.PROXIES_LIST]
 
     def pre_check(self, request: Request) -> Request:
@@ -129,7 +128,7 @@ class UpdateRequestSpiderInterceptor(_InnerSpiderInterceptor):
                             wrapper.websocket_pool.acquire_from_url(url=result.url)
                         else:
                             error_text = f'WebSocket connection {result.websocket_id} has been closed, but a new WebSocketRequest was received'
-                            self.logger.warning(f'{error_text}: {result.send_message.decode()}')
+                            self.logger.warning(f'{error_text}: {result.send_message}')
                             return SessionEndError(exception=ValueError(error_text), request=result)
         return result
     
