@@ -186,6 +186,15 @@ class KafkaLoggingHandler(logging.Handler):
                     await self.kafka.produce(self.topic, msg)
                 finally:
                     self.queue.task_done()
+                    
+                # try:
+                #     msg = await asyncio.wait_for(self.queue.get(), timeout=3.0)
+                #     try:
+                #         await self.kafka.produce(self.topic, msg)
+                #     finally:
+                #         self.queue.task_done()
+                # except asyncio.TimeoutError:
+                #     pass
             raise
         except Exception as e:
             print(f"Kafka send failed: {e}")
@@ -204,7 +213,7 @@ class KafkaLoggingHandler(logging.Handler):
         self.stop_event.set()
 
         if self.task and not self.task.done():
-            loop = asyncio.get_event_loop()
+            loop = asyncio.get_running_loop()
             # Run the sender task to completion synchronously
             future = asyncio.run_coroutine_threadsafe(self.task, loop)
             try:
